#
# spec file for package libXi
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libXi
%define lname   libXi6
Version:        1.7.5
Release:        8.1
Summary:        X Input Extension library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXi
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXi/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
Patch9:         U_Properly-validate-server-responses.patch
Patch10:        U_SizeClassInfo-can-return-0-even-without-an-error.patch
Patch11:        U_XListInputDevices-dont-touch-ndevices-in-case-of-error.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(inputproto) >= 2.1.99.6
BuildRequires:  pkgconfig(x11) >= 1.4.99.1
BuildRequires:  pkgconfig(xext) >= 1.0.99.1
BuildRequires:  pkgconfig(xextproto) >= 7.0.3
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
BuildRequires:  pkgconfig(xproto) >= 7.0.13

%description
libXi is the client-side library for the X Input Extension.

%package -n %lname
Summary:        X Input Extension library
Group:          System/Libraries

%description -n %lname
libXi is the client-side library for the X Input Extension.

%package devel
Summary:        Development files for the X Input Extension library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       libXi6-devel = %version-%release
Obsoletes:      libXi6-devel < %version-%release

%description devel
libXi is the client-side library for the X Input Extension.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q
%patch9 -p1
%patch10 -p1
%patch11 -p1

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXi.so.6*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXi.so
%_libdir/pkgconfig/xi.pc
%_docdir/%name
%_mandir/man3/*

%changelog
* Fri Jul 21 2017 msrb@suse.com
- U_SizeClassInfo-can-return-0-even-without-an-error.patch,
  U_XListInputDevices-dont-touch-ndevices-in-case-of-error.patch
  * Do not falsely return error for some devices (e.g. tablets).
    It can also cause crashes in GTK applications. (bnc#1049681)
* Wed Oct  5 2016 sndirsch@suse.com
- U_Properly-validate-server-responses.patch
  * insufficient validation of data from the X server can cause out
    of boundary memory access or endless loops (Denial of Service).
    (bnc#1002998, CVE-2016-7945, CVE-2016-7946)
* Fri Sep 11 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7.5:
  A couple of important bugfixes that have accumulated over the last
  year.
  + Fix version check in _XIAllowEvents
  + Advance the request buffer by the right amount in XIChangeHierarchy
  + Fix double unlock when _XiCheckExtInit return -1.
  + XIChangeHierarchy: Add missing unlock.
  + Do not return NoSuchExtension casted to pointer as an error.
  + XIGetClientPointer: Return False on error.
  + Fix logic in _XIAllowEvents and prevent double unlock.
  + Refactor XGetExtensionVersion.
  + XIGrabDevice: Unlock display in error path.
* Fri Jul 18 2014 sndirsch@suse.com
- Update to version 1.7.4
  * Fix locking bugs with XIAllowTouchEvents() and XIUngrabTouchBegin()
* Fri Jul 11 2014 sndirsch@suse.com
- Update to version 1.7.3
  * Two important patches fixing deadlocks when using XIPassiveGrab
    requests.  You're recommended to updated. Note that we now
    require libX11 1.6, that's a new dependency over 1.7.2 but it's
    over a year old by now anyway.
- added baselibs.conf as source to specfile
* Wed Jul  3 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7.2:
  Only one minor change since the RC. Again, this release contains the fixes
  for CVE-2013-1998, CVE-2013-1984 and CVE-2013-1995 so you're encouraged to
  update.
  + Remove check that can never be true.
* Fri Jun 28 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7.1.901:
  First and likely only RC for libXi 1.7.2. This one has a bunch of changes
  for CVE-2013-1998, CVE-2013-1984 and CVE-2013-1995. These relate to various
  integer overflows and other corruption that happens if we trust the server
  a bit too much on the data we're being sent.
  On top of those fixes, the sequence number in XI2 events is now set
  propertly too (#64687).
* Fri Apr  5 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7.1:
  Only a single fix: including the XFixes header to get the typedef for
  PointerBarrier. Naturally, this adds a pkgconfig build-time dependency on
  XFixes.
  Why? The header shipped with 1.7 typedef'd PointerBarrier. If you #include
  both XI and Xfixes headers, you will end up with a duplicate typedef.
  This is not an issue on gcc >= 4.6 since the two typedef's are the same.
  On earlier versions this will trigger an error. gcc 4.6 -pedantic-errors
  will trigger the same error.
* Tue Mar 19 2013 jengelh@inai.de
- Use more robust make install call
- Avoid calling fdupes outside of /usr
* Thu Mar  7 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.7:
  The feature added in this revision is pointer barrier events and releases.
  Pointer barriers themselves are an XFixes 5 feature, XI 2.3 adds two
  disctinct features to barriers:
  + the ability for clients to get notified if pointer movement is restricted
    by a barrier
  + the ability for clients to allow a pointer to move through a barrier
    after it was constrained by the barrier
  For a more verbose explanation of these features please refer to:
  http://who-t.blogspot.com.au/2012/12/whats-new-in-xi-23-pointer-barrier.html
* Wed May  9 2012 vuntz@opensuse.org
- Update to version 1.6.1:
  + Major bugs fixed:
  - wrong button and mask copy
  - raw event sourceid is now set
  + Small cleanups and bug fixes.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.6.0:
  + Implement XI 2.2 (which provides multitouch)
  + Various cleanups and bug fixes
- Changes from version 1.5.0:
  + Implement XI 2.1 (which provides smooth scrolling)
  + Various cleanups and bug fixes
  + Man page improvements
- Changes from version 1.4.2:
  + Various cleanups and bug fixes
  + Build configuration improvements
- Changes from version 1.4.1:
  + Important fixes for bugs that cause clients to misbehave.
* Sun Feb 12 2012 jengelh@medozas.de
- Update homepage URL and set a minimal package description
  (found one in tarball announcement mails)
* Fri Feb 10 2012 sndirsch@suse.com
- improved -devel provides/obsoletes for openSUSE 12.2
* Fri Feb 10 2012 sndirsch@suse.com
- added provides/obsoletes for old libXi6-devel package
* Thu Feb  9 2012 jengelh@medozas.de
- Rename SRPM from libXi6 to libXi (no Obsoletes needed for BRPMs)
* Sun Feb  5 2012 jengelh@medozas.de
- Remove apparently unused (Build)Requires on Xau, Xdmcp, xtrans
- Add required runtime dependency on libXext-devel
  (XInput2.h uses libXext-devel:Xge.h)
- Use pkgconfig() symbols to pull in BuildRequires
- Remove redundant tags/sections like %%clean
- Parallel build with %%_smp_mflags
* Wed Nov  3 2010 sndirsch@novell.com
- update to release 1.4.0
  * This version doesn't add new features but has seen numerous
    packaging cleanups and a number of miscellaneous fixes.
* Sat Sep  4 2010 sndirsch@novell.com
- update to release 1.3.1
  A few minor build system cleanups but I've cherry-picked only
  those that didn't require a macros update for this version. The
  requirements are thus the same as for 1.3.0.
  A couple of random other fixes, most notably two display lock
  fixes. The other fix that's quite prominent is the
  initialization of the extension with a server-specific number of
  events. Previously, libXi 1.3 running against a non-XI2 enabled
  server would result in mishandling of events (pending extension
  initialization order).
- update to release 1.3.2
  Brown paper bag release. Just one commit, fixing up a erroneous
  conflict resolution that resulted in an inverted condition for
  the asciidoc/xmlto checks and an error when building man pages.
* Fri Apr  2 2010 sndirsch@suse.de
- use real version number instead of the one from X.Org
* Sat Jan 16 2010 sndirsch@suse.de
- created package
